==> plasma-workspace_5.27.11.orig.tar.xz: plasma-workspace-5.27.11/krunner/org.kde.krunner.desktop.cmake <==
[Desktop Entry]
Exec=@CMAKE_INSTALL_PREFIX@/bin/krunner
Name=KRunner
Name[ar]=مشغّل.ك
Name[az]=KRunner
Name[be]=KRunner
Name[bg]=KRunner
Name[bs]=KPokretač
Name[ca]=KRunner
Name[ca@valencia]=KRunner
Name[cs]=KRunner
Name[da]=KRunner
Name[de]=KRunner
Name[el]=KRunner
Name[en_GB]=KRunner
Name[eo]=KRunner
Name[es]=KRunner
Name[et]=KRunner
Name[eu]=KRunner
Name[fi]=KRunner
Name[fr]=KRunner
Name[gl]=KRunner
Name[hi]=केरनर
Name[hu]=KRunner
Name[ia]=KRunner
Name[id]=KRunner
Name[is]=KRunner
Name[it]=KRunner
Name[ja]=KRunner
Name[ka]=KRunner
Name[ko]=KRunner
Name[lt]=KRunner
Name[ml]=കെറെണ്ണർ
Name[nb]=KRunner
Name[nds]=KRunner
Name[nl]=KRunner
Name[nn]=KRunner
Name[pa]=ਕੇਰਨਰ
Name[pl]=KRunner
Name[pt]=KRunner
Name[pt_BR]=KRunner
Name[ro]=KRunner
Name[ru]=Открыть строку поиска и запуска KRunner
Name[sk]=KRunner
Name[sl]=KRunner
Name[sr]=К‑извођач
Name[sr@ijekavian]=К‑извођач
Name[sr@ijekavianlatin]=K‑izvođač
Name[sr@latin]=K‑izvođač
Name[sv]=Kör program
Name[ta]=கேரன்னர்
Name[tr]=KRunner
Name[uk]=KRunner
Name[vi]=KRunner
Name[x-test]=xxKRunnerxx
Name[zh_CN]=KRunner
Name[zh_TW]=KRunner
Icon=krunner
OnlyShowIn=KDE;
Type=Application
DBusActivatable=True
X-DBUS-StartupType=Unique
X-DBUS-ServiceName=org.kde.krunner
X-KDE-StartupNotify=false
X-KDE-Shortcuts=Alt+Space,Alt+F2,Search
Actions=RunClipboard
X-KDE-Wayland-Interfaces=org_kde_plasma_window_management

[Desktop Action RunClipboard]
Exec=krunner -c
Name=Run command on clipboard contents
Name[ar]=شغل أمر في محتويات الحافظة
Name[az]=Əmri, mübadilə buferindən başlatmaq
Name[be]=Выкананне загаду са змесцівам буфера абмену
Name[bg]=Изпълняване на команда от съдържанието на клипборда
Name[ca]=Executa una ordre al contingut del porta-retalls
Name[ca@valencia]=Executa una ordre al contingut del porta-retalls
Name[cs]=Spustit příkaz nad obsahem schránky
Name[da]=Kør kommando på udklipsholderindholdet
Name[de]=Befehl mit dem Inhalt der Zwischenablage ausführen
Name[en_GB]=Run command on clipboard contents
Name[eo]=Lanĉi komandon sur tonduja enhavo
Name[es]=Ejecutar orden sobre el contenido del portapapeles
Name[et]=Käsu käivitamine lõikepuhvri sisuga
Name[eu]=Exekutatu komandoa arbelaren edukiaren gain
Name[fi]=Suorita komento leikepöydän sisällöstä
Name[fr]=Exécuter la commande en utilisant le contenu du presse-papier
Name[gl]=Executar a orde segundo o contido do portapapeis
Name[hi]=क्लिपबोर्ड सामग्री पर समादेश चलाएँ
Name[hsb]=Wuwjedźe přikazy na wobsahu zapisnika
Name[hu]=Parancs futtatása a vágólap tartalmával
Name[ia]=Executa  commando sur contentos de area de transferentia
Name[id]=Jalankan perintah pada konten papan klip
Name[is]=Keyra skipun á innihald klippiborðsins
Name[it]=Esegui comando sui contenuti degli appunti
Name[ja]=クリップボードのコマンドを実行する
Name[ka]=ბუფერის შემცველობაზე ბრძანების გაშვება
Name[ko]=클립보드 내용에서 명령 실행하기
Name[lt]=Vykdyti komandas su iškarpinės turiniu
Name[ml]=ഓര്‍മ്മചെപ്പ് ഉള്ളടക്കങ്ങളിൽ ആജ്ഞ പ്രവർത്തിപ്പിക്കുക
Name[nl]=Commando uitvoeren op klembordinhoud
Name[nn]=Køyr kommando på innhaldet på utklippstavla
Name[pa]=ਕਲਿੱਪਬੋਡ ਸਮੱਗਰੀ ਉੱਤੇ ਕਮਾਂਡ ਚਲਾਓ
Name[pl]=Wykonaj polecenie na zawartości schowka
Name[pt]=Executar o comando no conteúdo da área de transferência
Name[pt_BR]=Executar comando no conteúdo da área de transferência
Name[ro]=Rulează comandă pe conținutul clipboard-ului
Name[ru]=Запустить команду из буфера обмена
Name[sk]=Spustiť príkaz na obsahu schránky
Name[sl]=Zaženi ukaz na vsebini odložišča
Name[sv]=Kör kommando med klippbordets innehåll
Name[ta]=பிடிப்புப்பலகையின் உள்ளடக்கம் மீது கட்டளையை இயக்கு
Name[tr]=Pano içeriğinde komut çalıştır
Name[uk]=Виконати команду над вмістом буфера обміну
Name[vi]=Chạy lệnh với nội dung bảng nháp
Name[x-test]=xxRun command on clipboard contentsxx
Name[zh_CN]=在剪贴板内容上运行命令
Name[zh_TW]=執行剪貼簿內容中的指令
X-KDE-Shortcuts=Alt+Shift+F2

==> plasma-workspace-5.92.0.tar.xz: plasma-workspace-5.92.0/krunner/org.kde.krunner.desktop.cmake <==
[Desktop Entry]
Exec=@CMAKE_INSTALL_PREFIX@/bin/krunner
Name=KRunner
Name[ar]=مشغّل.ك
Name[ast]=KRunner
Name[az]=KRunner
Name[be]=KRunner
Name[bg]=KRunner
Name[bs]=KPokretač
Name[ca]=KRunner
Name[ca@valencia]=KRunner
Name[cs]=KRunner
Name[da]=KRunner
Name[de]=KRunner
Name[el]=KRunner
Name[en_GB]=KRunner
Name[eo]=KRunner
Name[es]=KRunner
Name[et]=KRunner
Name[eu]=KRunner
Name[fi]=KRunner
Name[fr]=KRunner
Name[gl]=KRunner
Name[he]=KRunner
Name[hi]=केरनर
Name[hu]=KRunner
Name[ia]=KRunner
Name[id]=KRunner
Name[is]=KRunner
Name[it]=KRunner
Name[ja]=KRunner
Name[ka]=KRunner
Name[ko]=KRunner
Name[lt]=KRunner
Name[ml]=കെറെണ്ണർ
Name[nb]=KRunner
Name[nds]=KRunner
Name[nl]=KRunner
Name[nn]=KRunner
Name[pa]=ਕੇਰਨਰ
Name[pl]=KRunner
Name[pt]=KRunner
Name[pt_BR]=KRunner
Name[ro]=KRunner
Name[ru]=Открыть строку поиска и запуска KRunner
Name[sa]=KRunner
Name[sk]=KRunner
Name[sl]=KRunner
Name[sr]=К‑извођач
Name[sr@ijekavian]=К‑извођач
Name[sr@ijekavianlatin]=K‑izvođač
Name[sr@latin]=K‑izvođač
Name[sv]=Kör program
Name[ta]=கேரன்னர்
Name[tr]=K Çalıştır
Name[uk]=KRunner
Name[vi]=KRunner
Name[x-test]=xxKRunnerxx
Name[zh_CN]=KRunner
Name[zh_TW]=KRunner
Icon=krunner
OnlyShowIn=KDE;
Type=Application
DBusActivatable=True
X-DBUS-StartupType=Unique
X-DBUS-ServiceName=org.kde.krunner
X-KDE-StartupNotify=false
X-KDE-Shortcuts=Alt+Space,Alt+F2,Search
Actions=RunClipboard
X-KDE-Wayland-Interfaces=org_kde_plasma_window_management

[Desktop Action RunClipboard]
Exec=krunner -c
Name=Run command on clipboard contents
Name[ar]=شغل أمر في محتويات الحافظة
Name[az]=Əmri, mübadilə buferindən başlatmaq
Name[be]=Выкананне загаду са змесцівам буфера абмену
Name[bg]=Изпълняване на команда от съдържанието на клипборда
Name[ca]=Executa una ordre al contingut del porta-retalls
Name[ca@valencia]=Executa una ordre al contingut del porta-retalls
Name[cs]=Spustit příkaz nad obsahem schránky
Name[da]=Kør kommando på udklipsholderindholdet
Name[de]=Befehl mit dem Inhalt der Zwischenablage ausführen
Name[en_GB]=Run command on clipboard contents
Name[eo]=Lanĉi komandon sur tonduja enhavo
Name[es]=Ejecutar orden sobre el contenido del portapapeles
Name[et]=Käsu käivitamine lõikepuhvri sisuga
Name[eu]=Exekutatu komandoa arbelaren edukiaren gain
Name[fi]=Suorita komento leikepöydän sisällöstä
Name[fr]=Exécuter la commande en utilisant le contenu du presse-papier
Name[gl]=Executar a orde segundo o contido do portapapeis
Name[he]=הרצת פקודה על תוכן לוח הגזירים
Name[hi]=क्लिपबोर्ड सामग्री पर समादेश चलाएँ
Name[hsb]=Wuwjedźe přikazy na wobsahu zapisnika
Name[hu]=Parancs futtatása a vágólap tartalmával
Name[ia]=Executa  commando sur contentos de area de transferentia
Name[id]=Jalankan perintah pada konten papan klip
Name[is]=Keyra skipun á innihald klippiborðsins
Name[it]=Esegui comando sui contenuti degli appunti
Name[ja]=クリップボードのコマンドを実行する
Name[ka]=ბუფერის შემცველობაზე ბრძანების გაშვება
Name[ko]=클립보드 내용에서 명령 실행하기
Name[lt]=Vykdyti komandas su iškarpinės turiniu
Name[ml]=ഓര്‍മ്മചെപ്പ് ഉള്ളടക്കങ്ങളിൽ ആജ്ഞ പ്രവർത്തിപ്പിക്കുക
Name[nl]=Commando uitvoeren op klembordinhoud
Name[nn]=Køyr kommando på innhaldet på utklippstavla
Name[pa]=ਕਲਿੱਪਬੋਡ ਸਮੱਗਰੀ ਉੱਤੇ ਕਮਾਂਡ ਚਲਾਓ
Name[pl]=Wykonaj polecenie na zawartości schowka
Name[pt]=Executar o comando no conteúdo da área de transferência
Name[pt_BR]=Executar comando no conteúdo da área de transferência
Name[ro]=Rulează comandă pe conținutul clipboard-ului
Name[ru]=Запустить команду из буфера обмена
Name[sa]=अंशफलक सामग्रीषु आदेशं चालयन्तु
Name[sk]=Spustiť príkaz na obsahu schránky
Name[sl]=Zaženi ukaz na vsebini odložišča
Name[sv]=Kör kommando med klippbordets innehåll
Name[ta]=பிடிப்புப்பலகையின் உள்ளடக்கம் மீது கட்டளையை இயக்கு
Name[tr]=Pano içeriğinde komut çalıştır
Name[uk]=Виконати команду над вмістом буфера обміну
Name[vi]=Chạy lệnh với nội dung bảng nháp
Name[x-test]=xxRun command on clipboard contentsxx
Name[zh_CN]=在剪贴板内容上运行命令
Name[zh_TW]=執行剪貼簿內容中的指令
X-KDE-Shortcuts=Alt+Shift+F2
